@@ -1,7 +1,7 @@
 /*
  * This file is part of Gtef, a text editor library.
  *
- * Copyright 2016 - Sébastien Wilmet <swilmet@gnome.org>
+ * Copyright 2016, 2017 - Sébastien Wilmet <swilmet@gnome.org>
  *
  * Gtef is free software; you can redistribute it and/or modify it under
  * the terms of the GNU Lesser General Public License as published by the
@@ -28,7 +28,12 @@
 
 G_BEGIN_DECLS
 
+typedef struct _GtefActionInfo			GtefActionInfo;
+typedef struct _GtefActionInfoEntry		GtefActionInfoEntry;
+typedef struct _GtefActionInfoStore		GtefActionInfoStore;
+typedef struct _GtefApplication			GtefApplication;
 typedef struct _GtefBuffer			GtefBuffer;
+typedef struct _GtefEncoding			GtefEncoding;
 typedef struct _GtefFile			GtefFile;
 typedef struct _GtefFileLoader			GtefFileLoader;
 typedef struct _GtefFileMetadata		GtefFileMetadata;
