@@ -20,6 +20,10 @@
 #ifndef GTEF_UTILS_H
 #define GTEF_UTILS_H
 
+#if !defined (GTEF_H_INSIDE) && !defined (GTEF_COMPILATION)
+#error "Only <gtef/gtef.h> can be included directly."
+#endif
+
 #include <gtk/gtk.h>
 
 G_BEGIN_DECLS
@@ -43,7 +47,12 @@ gchar *		_gtef_utils_get_fallback_basename_for_display	(GFile *location);
 /* String utilities */
 
 G_GNUC_INTERNAL
-gchar *		_gtef_utils_make_valid_utf8			(const gchar *_str);
+gchar **	_gtef_utils_strv_copy				(const gchar * const *strv);
+
+/* Widget utilities */
+
+void		gtef_utils_menu_item_set_icon_name		(GtkMenuItem *item,
+								 const gchar *icon_name);
 
 G_END_DECLS
 
