@@ -1,7 +1,7 @@
 /*
  * This file is part of Gtef, a text editor library.
  *
- * Copyright 2016 - Sébastien Wilmet <swilmet@gnome.org>
+ * Copyright 2016, 2017 - Sébastien Wilmet <swilmet@gnome.org>
  *
  * Gtef is free software; you can redistribute it and/or modify it under
  * the terms of the GNU Lesser General Public License as published by the
@@ -25,7 +25,11 @@
 #include <gtef/gtef-types.h>
 #include <gtef/gtef-enum-types.h>
 
+#include <gtef/gtef-action-info.h>
+#include <gtef/gtef-action-info-store.h>
+#include <gtef/gtef-application.h>
 #include <gtef/gtef-buffer.h>
+#include <gtef/gtef-encoding.h>
 #include <gtef/gtef-file.h>
 #include <gtef/gtef-file-loader.h>
 #include <gtef/gtef-file-metadata.h>
@@ -33,8 +37,10 @@
 #include <gtef/gtef-fold-region.h>
 #include <gtef/gtef-gutter-renderer-folds.h>
 #include <gtef/gtef-info-bar.h>
+#include <gtef/gtef-iter.h>
 #include <gtef/gtef-metadata-manager.h>
 #include <gtef/gtef-tab.h>
+#include <gtef/gtef-utils.h>
 #include <gtef/gtef-view.h>
 
 #undef GTEF_H_INSIDE
